"""
name_spec_instances.py
"""

population = [
    # Connector location names
    {'Connector location': 'binary association', 'Diagram type': 'class', 'Notation': 'Starr',
     'Vertical axis buffer': 6, 'Horizontal axis buffer': 6, 'Vertical end buffer': 11, 'Horizontal end buffer': 20,
     'Default name': 'Rxx', 'Optional': False},
    {'Connector location': 'generalization', 'Diagram type': 'class', 'Notation': 'Starr',
     'Vertical axis buffer': 13, 'Horizontal axis buffer': 16, 'Vertical end buffer': 11, 'Horizontal end buffer': 20,
     'Default name': 'Rxx', 'Optional': False},

    {'Connector location': 'binary association', 'Diagram type': 'class', 'Notation': 'xUML',
     'Vertical axis buffer': 11, 'Horizontal axis buffer': 11, 'Vertical end buffer': 11, 'Horizontal end buffer': 20,
     'Default name': 'Rxx', 'Optional': False},
    {'Connector location': 'generalization', 'Diagram type': 'class', 'Notation': 'xUML',
     'Vertical axis buffer': 11, 'Horizontal axis buffer': 11, 'Vertical end buffer': 11, 'Horizontal end buffer': 20,
     'Default name': 'Rxx', 'Optional': False},

    {'Connector location': 'binary association', 'Diagram type': 'class', 'Notation': 'Shlaer-Mellor',
     'Vertical axis buffer': 11, 'Horizontal axis buffer': 11, 'Vertical end buffer': 11, 'Horizontal end buffer': 20,
     'Default name': 'Rxx', 'Optional': False},
    {'Connector location': 'generalization', 'Diagram type': 'class', 'Notation': 'Shlaer-Mellor',
     'Vertical axis buffer': 11, 'Horizontal axis buffer': 11, 'Vertical end buffer': 11, 'Horizontal end buffer': 20,
     'Default name': 'Rxx', 'Optional': False},

    {'Connector location': 'transition', 'Diagram type': 'state machine', 'Notation': 'xUML',
     'Vertical axis buffer': 6, 'Horizontal axis buffer': 6, 'Vertical end buffer': 11, 'Horizontal end buffer': 20,
     'Default name': 'Event XX', 'Optional': False},

    {'Connector location': 'initial transition', 'Diagram type': 'state machine', 'Notation': 'xUML',
     'Vertical axis buffer': 6, 'Horizontal axis buffer': 6, 'Vertical end buffer': 11, 'Horizontal end buffer': 20,
     'Default name': 'Event XX', 'Optional': False},

    {'Connector location': 'deletion transition', 'Diagram type': 'state machine', 'Notation': 'xUML',
     'Vertical axis buffer': 6, 'Horizontal axis buffer': 6, 'Vertical end buffer': 11, 'Horizontal end buffer': 20,
     'Default name': 'Event XX', 'Optional': False},

    # Connector location names
    {'Connector location': 'class mult', 'Diagram type': 'class', 'Notation': 'Starr',
     'Vertical axis buffer': 8, 'Horizontal axis buffer': 8, 'Vertical end buffer': 10, 'Horizontal end buffer': 10,
     'Default name': 'xx', 'Optional': False},
]